documentationtools.GraphvizGraph
================================

.. abjad-lineage:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph

.. autoclass:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.attributes
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.canonical_name
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.children
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.depth
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.depthwise_inventory
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.edge_attributes
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.graph_order
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.graphviz_format
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.leaves
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.node_attributes
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.nodes
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.parent
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.root
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.storage_format
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.unflattened_graphviz_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.is_digraph
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.append
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.extend
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.index
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.insert
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.pop
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.remove
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.__contains__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.__delitem__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.__ge__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.__getitem__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.__getstate__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.__gt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.__iter__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.__le__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.__len__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.__lt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.__repr__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.__setitem__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph.GraphvizGraph.__setstate__
   :noindex:
